@@ -3,7 +3,7 @@
 /*
  *  Author: Michael Roth <mroth@nessie.de>
  *
- *  Copyright (c) 2004 Michael Roth <mroth@nessie.de>
+ *  Copyright (c) 2004, 2005 Michael Roth <mroth@nessie.de>
  *
  *  Permission is hereby granted, free of charge, to any person 
  *  obtaining a copy of this software and associated documentation
@@ -449,6 +449,17 @@ FUNC( l_sqlite3_bind_parameter_name )
 }
 
 
+FUNC( l_sqlite3_bind_parameter_name_x )
+{
+  const char * name = sqlite3_bind_parameter_name(checkstmt_stmt(L, 1), checkint(L, 2));
+  if (name)
+    lua_pushstring(L, name + 1);	/* Ignore leading '$' or ':' */
+  else
+    lua_pushnil(L);
+  return 1;
+}
+
+
 FUNC( l_sqlite3_busy_timeout )
 {
   DB * db	= checkdb(L, 1);
@@ -1478,6 +1489,7 @@ f_entry api_entries[] = {
   { "bind_number",		l_sqlite3_bind_number },
   { "bind",			l_sqlite3_bind },
   { "bind_parameter_name",	l_sqlite3_bind_parameter_name },
+  { "bind_parameter_name_x",	l_sqlite3_bind_parameter_name_x },
   { "bind_parameter_count",	l_sqlite3_bind_parameter_count },
   { "busy_timeout",		l_sqlite3_busy_timeout },
   { "changes",			l_sqlite3_changes },
